Welcome to skypac's documentation!
==================================

Content
=======

.. toctree::
   :maxdepth: 2

   skymatch
   skyline
   parseat
   region
   skystatistics
   utils
   pamutils
   LICENSE.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

